@@ -30,6 +30,7 @@
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
+#define HAVE_FCNTL_DIRECT 1
 #define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
@@ -72,6 +73,7 @@
 #define HAVE_SYS_IOCTL_H 1
 #define HAVE_SYS_MALLOC_H 1
 #define HAVE_SYS_MMAN_H 1
+/* #undef HAVE_SYS_MNTENT_H */
 /* #undef HAVE_SYS_NDIR_H */
 /* #undef HAVE_SYS_PTE_H */
 /* #undef HAVE_SYS_PTEM_H */
@@ -231,7 +233,6 @@
 #define HAVE_STRTOUL 1
 #define HAVE_STRTOULL 1
 /* #undef HAVE_TELL */
-/* #undef HAVE_THR_SETCONCURRENCY */
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
@@ -277,10 +278,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   4
-#define SIZEOF_VOIDP  4
-#define SIZEOF_CHARP  4
-#define SIZEOF_SIZE_T 4
+#define SIZEOF_LONG   8
+#define SIZEOF_VOIDP  8
+#define SIZEOF_CHARP  8
+#define SIZEOF_SIZE_T 8
 #endif
 
 #define HAVE_LONG 1
@@ -295,7 +296,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 4
+#define SIZEOF_ULONG 8
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -394,8 +395,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "NetBSD"
-#define MACHINE_TYPE "powerpc"
-#define DEFAULT_MACHINE "powerpc"
+#define MACHINE_TYPE "sparc64"
+#define DEFAULT_MACHINE "sparc64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -498,6 +499,7 @@
 #define HAVE_COMPRESS 1
 #define HAVE_EncryptAes128Ctr 1
 #define HAVE_EncryptAes128Gcm 1
+#define HAVE_des 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -530,16 +532,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 16
+#define MYSQL_VERSION_PATCH 19
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.16"
+#define PACKAGE_STRING "MySQL Server 10.6.19"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.16"
-#define VERSION "10.6.16"
+#define PACKAGE_VERSION "10.6.19"
+#define VERSION "10.6.19"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
